# ElasticAnisotropy

ElasticAnisotropy.py constructs the Voigt Matrix and the elastic tensor from the elastic moduli and rotates it around a given axis.
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5791436.svg)](https://doi.org/10.5281/zenodo.5791436)
